#!/bin/sh

config_new() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ] ; then
    mv $NEW $OLD
	chmod 644 $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ] ; then
  # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
# these files are non-modified original versions
config_new etc/rc.d/rc.inet1.conf.new
config_new etc/rc.d/rc.wireless.conf.new
config_new etc/inittab.new

# If installing fresh, then all scripts gets renamed to drop the '.dash' suffix
# If the standard bash scripts are already installed, then rename them to add '.bash' suffix
# and then rename the new scripts to the simple 'real' names.
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .dash`"
  if [ -x $OLD ] ; then
    chmod o+x $NEW
  else
    chmod o-x $NEW
  fi
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ] ; then
    # if they are the same, toss the redundant copy
    rm $NEW
  else
    # otherwise, rename the original version if it a bin/sh script
	if [ `head -n1 $OLD |grep 'bin/sh'` ] ; then
		mv $OLD $OLD.bash
		# and replace with the new version
		mv $NEW $OLD
	else
		# Otherwise, overwrite with the new version
		mv $NEW $OLD
	fi
  fi
}

# Main runlevel scripts
config etc/rc.d/rc.4.dash
config etc/rc.d/rc.6.dash
config etc/rc.d/rc.K.dash
config etc/rc.d/rc.M.dash
config etc/rc.d/rc.S.dash

# activated scripts called by rc.S
config etc/rc.d/rc.udev.dash
config etc/rc.d/rc.fuse.dash

# inactivated scripts called by rc.S
config etc/rc.d/rc.lvm.dash
config etc/rc.d/rc.cryptsetup.dash
config etc/rc.d/rc.modules.local.dash
config etc/rc.d/rc.sysvinit.dash
config etc/rc.d/rc.serial.dash

# activated scripts called by rc.M
config etc/rc.d/rc.screenblank.dash
config etc/rc.d/rc.syslog.dash
config etc/rc.d/rc.alsa.dash

#inactivated scripts called by rc.M
config etc/rc.d/rc.inet1.dash
config etc/rc.d/rc.scanluns.dash
config etc/rc.d/rc.inet2.dash
config etc/rc.d/rc.wireless.dash
config etc/rc.d/rc.local.dash

# extra files called by rc.6
config etc/rc.d/rc.local_shutdown.dash


#config etc/rc.d/rc.pcmcia.dash
#config etc/rc.d/rc.ntpd.dash
#config etc/rc.d/rc.acpid.dash
#config etc/rc.d/rc.messagebus.dash
#config etc/rc.d/rc.hald.dash
#config etc/rc.d/rc.bluetooth.dash
#config etc/rc.d/rc.wicd.dash
#config etc/rc.d/rc.dnsmasq.dash
#config etc/rc.d/rc.snmpd.dash
#config etc/rc.d/rc.cups.dash
#config etc/rc.d/rc.lprng.dash
#config etc/rc.d/rc.atalk.dash
#config etc/rc.d/rc.saslauthd.dash
#config etc/rc.d/rc.sendmail.dash
#config etc/rc.d/rc.mysqld.dash
#config etc/rc.d/rc.httpd.dash
#config etc/rc.d/rc.samba.dash
#config etc/rc.d/rc.gpm.dash
# missing rc.openldap

( cd etc/rc.d ; rm -rf rc.0 )
( cd etc/rc.d ; ln -sf rc.6 rc.0 )

# if someone installs this package, but dash is not already installed,
# then link /bin/initssh to /bin/ash, fi present.
# Otherwise, link to /bin/sh
if ! [ -x bin/initsh ] ; then
	if [ -x bin/dash ] ; then
		( cd bin ; ln -sf dash initsh )
	elif [ -x bin/ash ] ; then
		( cd bin ; ln -sf ash initsh )
	else
		( cd bin ; ln -sf sh initsh )
	fi
fi
